Timer

Struct Timer 

pub struct Timer { /* private fields */ }
Timer peripheral

Implementations

Source

impl Timer

pub fn new(timer: TIMER, resets: &mut RESETS, _clocks: &ClocksManager) -> Self

Create a new Timer

Make sure that clocks and watchdog are configured, so that timer ticks happen at a frequency of 1MHz. Otherwise, Timer won’t work as expected.

pub fn get_counter(&self) -> Instant

Get the current counter value.

pub fn get_counter_low(&self) -> u32

Get the value of the least significant word of the counter.

pub fn count_down(&self) -> CountDown

Initialized a Count Down instance without starting it.

pub fn alarm_0(&mut self) -> Option<Alarm0>

Retrieve a reference to alarm 0. Will only return a value the first time this is called

pub fn alarm_1(&mut self) -> Option<Alarm1>

Retrieve a reference to alarm 1. Will only return a value the first time this is called

pub fn alarm_2(&mut self) -> Option<Alarm2>

Retrieve a reference to alarm 2. Will only return a value the first time this is called

pub fn alarm_3(&mut self) -> Option<Alarm3>

Retrieve a reference to alarm 3. Will only return a value the first time this is called