pub struct Writer<D: UartDevice, P: ValidUartPinout<D>> { /* private fields */ }Expand description
Half of an UartPeripheral that is only capable of writing. Obtained by calling UartPeripheral::split()
Implementations
Sourceimpl<D: UartDevice, P: ValidUartPinout<D>> Writer<D, P>
impl<D: UartDevice, P: ValidUartPinout<D>> Writer<D, P>
Sourcepub fn write_raw<'d>(&self, data: &'d [u8]) -> Result<&'d [u8], Infallible>
pub fn write_raw<'d>(&self, data: &'d [u8]) -> Result<&'d [u8], Infallible>
Writes bytes to the UART.
This function writes as long as it can. As soon that the FIFO is full, if:
- 0 bytes were written, a WouldBlock Error is returned
- some bytes were written, it is deemed to be a success
Upon success, the remaining (unwritten) slice is returned.
Sourcepub fn write_full_blocking(&self, data: &[u8])
pub fn write_full_blocking(&self, data: &[u8])
Writes bytes to the UART.
This function blocks until the full buffer has been sent.
Sourcepub fn enable_tx_interrupt(&mut self)
pub fn enable_tx_interrupt(&mut self)
Enables the Transmit Interrupt.
The relevant UARTx IRQ will fire when there is space in the transmit FIFO.
Sourcepub fn disable_tx_interrupt(&mut self)
pub fn disable_tx_interrupt(&mut self)
Disables the Transmit Interrupt.
Sourcepub fn lowlevel_break_start(&mut self)
pub fn lowlevel_break_start(&mut self)
Initiates a break
If transmitting, this takes effect immediately after the current byte has completed.
For proper execution of the break command, this must be held for at least 2 complete frames
worth of time.
Example
serial.lowlevel_break_start();
// at 115_200Bps on 8N1 configuration, 20bits takes (20*10⁶)/115200 = 173.611…μs.
timer.delay_us(175);
serial.lowlevel_break_stop();Sourcepub fn lowlevel_break_stop(&mut self)
pub fn lowlevel_break_stop(&mut self)
Terminates a break condition.
See lowlevel_break_start for more details.