pub unsafe extern "C" fn flash_range_program(
addr: u32,
data: *const u8,
count: usize,
)Expand description
Program data to a range of flash addresses starting at addr (and
offset from the start of flash) and count bytes in size.
The value addr must be aligned to a 256-byte boundary, and count must be a
multiple of 256.
Safety
This is a low-level C function. It may be difficult to call safely from Rust. If in doubt, check the RP2040 datasheet for details and do your own safety evaluation.