pub struct Timer { /* private fields */ }Expand description
Timer peripheral
Implementations
Sourceimpl Timer
impl Timer
Sourcepub fn new(timer: TIMER, resets: &mut RESETS, _clocks: &ClocksManager) -> Self
pub fn new(timer: TIMER, resets: &mut RESETS, _clocks: &ClocksManager) -> Self
Create a new Timer
Make sure that clocks and watchdog are configured, so
that timer ticks happen at a frequency of 1MHz.
Otherwise, Timer won’t work as expected.
Sourcepub fn get_counter(&self) -> Instant
pub fn get_counter(&self) -> Instant
Get the current counter value.
Sourcepub fn get_counter_low(&self) -> u32
pub fn get_counter_low(&self) -> u32
Get the value of the least significant word of the counter.
Sourcepub fn count_down(&self) -> CountDown
pub fn count_down(&self) -> CountDown
Initialized a Count Down instance without starting it.
Sourcepub fn alarm_0(&mut self) -> Option<Alarm0>
pub fn alarm_0(&mut self) -> Option<Alarm0>
Retrieve a reference to alarm 0. Will only return a value the first time this is called
Sourcepub fn alarm_1(&mut self) -> Option<Alarm1>
pub fn alarm_1(&mut self) -> Option<Alarm1>
Retrieve a reference to alarm 1. Will only return a value the first time this is called